KW_BATCH = 'Batch'
KW_BULK = 'Bulk'
KW_ALL = 'All'

CONTROLLER_TYPE_LIST = [
    KW_BATCH,
    KW_BULK,
    KW_ALL
]
